@@ -669,51 +669,3 @@ toLatex.setar <- function(object, digits=3, ...) {
   return(structure(res, class="Latex"))
 }
 
-showDialog.setar <- function(x, ...) {
-  vD <- tclVar(1)
-  vSteps <- tclVar(1)
-  vML  <- tclVar(1)
-  vMH  <- tclVar(1)
-  vThDelay <- tclVar(0)
-  vFixedTh <- tclVar(0)
-  vTh <- tclVar(0)
-
-  frTop <- Frame(opts=list(side="left"))
-  frLeft <- Frame()
-  add(frLeft,
-      namedSpinbox("low reg. AR order", vML, from=1, to=1000, increment=1, width=4),
-      namedSpinbox("high reg. AR order", vMH, from=1, to=1000, increment=1, width=4))
-  frRight <- Frame()
-  add(frRight,
-      Widget(opts=list(type="checkbutton", text="fixed treshold", variable=vFixedTh)),
-      namedEntry("treshold value", vTh, width=4),
-      namedSpinbox("treshold delay", vThDelay, from=0, to=1000))
-  frExtra <- Frame()
-  add(frExtra,
-      namedSpinbox("time delay", vD, from=1, to=1000),
-      namedSpinbox("forecasting steps", vSteps, from=1, to=1000))
-  add(frTop, frExtra, frLeft, frRight)
-  frRoot <- Frame()
-
-  onFinish <- function() {
-    d <- as.numeric(tclObj(vD))
-    steps <- as.numeric(tclObj(vSteps))
-    mL <- as.numeric(tclObj(vML))
-    mH <- as.numeric(tclObj(vMH))
-    fixedTh <- as.logical(tclObj(vFixedTh))
-    th <- as.numeric(tclObj(vTh))
-    thDelay <- as.numeric(tclObj(vThDelay))
-    tkdestroy(frRoot$tkvar)
-    if(fixedTh)
-      res <- setar(x, d=d, steps=steps, mL=mL, mH=mH, th=th, thDelay=thDelay)
-    else
-      res <- setar(x, d=d, steps=steps, mL=mL, mH=mH, thDelay=thDelay)
-    assign("nlarModel", res, .GlobalEnv)
-  }
-  onCancel <- function()
-    tkdestroy(frRoot$tkvar)
-
-  bttnFrame <- makeButtonsFrame(list(Finish=onFinish, Cancel=onCancel))
-  add(frRoot, frTop, bttnFrame)
-  buildDialog(title="SETAR model", frRoot)
-}
